summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--server/src/main/java/com/vaadin/ui/themes/ValoTheme.java10
1 files changed, 8 insertions, 2 deletions
diff --git a/server/src/main/java/com/vaadin/ui/themes/ValoTheme.java b/server/src/main/java/com/vaadin/ui/themes/ValoTheme.java
index 0f5a09c1b9..3ec3b66c85 100644
--- a/server/src/main/java/com/vaadin/ui/themes/ValoTheme.java
+++ b/server/src/main/java/com/vaadin/ui/themes/ValoTheme.java
@@ -100,13 +100,13 @@ public class ValoTheme {
/**
* Success notification style. Adds a border around the notification and an
* icon next to the title. Can be combined with any other Label style.
*/
public static final String NOTIFICATION_SUCCESS = "success";
/**
* Failure notification style. Adds a border around the notification and an
* icon next to the title. Can be combined with any other Label style.
*/
public static final String NOTIFICATION_FAILURE = "failure";
@@ -117,6 +117,12 @@ public class ValoTheme {
*/
public static final String NOTIFICATION_CRITICAL_ERROR = "critical-error";
+ /**
+ * Styles the notification to be dark variant. Can be combined with any
+ * other Notification style.
+ */
+ public static final String NOTIFICATION_DARK = "dark";
+
/***************************************************************************
*
* Label styles
@@ -100,13 +100,13 @@ public class ValoTheme {
/**
* Success notification style. Adds a border around the notification and an
- * icon next to the title. Can be combined with any other Label style.
+ * icon next to the title. Can be combined with any other Notification style.
*/
public static final String NOTIFICATION_SUCCESS = "success";
@@ -100,13 +100,13 @@ public class ValoTheme {
/**
* Failure notification style. Adds a border around the notification and an
- * icon next to the title. Can be combined with any other Label style.
+ * icon next to the title. Can be combined with any other Notification style.
*/
public static final String NOTIFICATION_FAILURE = "failure";